+++
date = '2023-03-22T18:59:00Z'
draft = false
title = 'Empieza a respaldar tus datos de inmediato'
categories = ['Software']
tags = ['Arch Linux', 'archivos', 'clonezilla', 'copia', 'copias', 'data', 'dd', 'disco', 'Filen', 'Linux', 'Respaldo', 'Respaldos', 'Rufus', 'Windows']
+++

Tu data se encuentra en sólo dos estados: respaldada múltiples veces, o perdida. Si no lo habías considerado antes, piénsalo por un momento: lo que sea que no tengas copiado, ya no lo tienes; sólo es cuestión de tiempo para que desaparezca.

Los discos tienen un tiempo de vida limitado, ya sean HDD, SSD, NVMe o de cualquier clase. Por supuesto, esto también aplica a los dispositivos de almacenamiento portátil tales como los mismos discos, memorias USB, tarjetas SD y demás. Es por ello que cualquier data que sea importante para ti no sólo debe ser respaldada, si no que la mejor práctica para ello es que lo hagas de múltiples maneras.

<!--more-->

### Planeando un esquema de respaldos

Por supuesto, no hay una solución universal que aplique a cada caso; cómo se debe diseñar un plan de respaldos dependerá en gran manera de cada caso particular. Lo que propongo aquí es una estrategia que me ha servido bastante bien para la mayoría de los casos, pero hago hincapié en que debes ajustarla según tus necesidades en caso de que sea necesario.

Este esquema que propongo es bastante popular, y lo llamo «la estrategia de triple respaldo». Consiste en copiar tu data en tres lugares distintos. Aunque puedes elegir entre los medios que se te antojen, de igual manera sugiero que sean distintos: no vale de mucho copiar tres veces tu data en el mismo disco, ya que en el momento en que falle, perderás todas las copias.

Te daré un ejemplo detallando el método que me gusta usar:

* Un primer respaldo en un disco local distinto al que originalmente almacena la data. Si tu data reside en «disco 1», lo copias a un disco secundario que podemos llamar «disco 2».
* Un segundo respaldo de la data en «disco 1» a un disco externo, preferiblemente portátil. Podemos llamarlo «disco portátil 1». También sugeriría almacenar este disco en alguna habitación fuera de dónde está tu computadora; así, si es destruida, este disco estaría aislado y a salvo, lo que garantizaría que tu data no se pierda junto a tu PC.
* Por último, un tercer respaldo de la data del «disco 1» a un servicio de alojamiento en la nube. Para ello sería imperativo que encriptes tus respaldos antes de subirlos; después de todo, se trata de un servidor ajeno en la mayoría de los casos. Si andas buscando un servicio confiable, yo recomiendo [Filen](https://filen.io); si deseas, puedes utilizar [mi enlace de afiliado](https://filen.io/r/db7eda9ec8de920c00f6eb235a824657) y de paso recibir diez gigas adicionales de manera gratuita. Con un respaldo que se encuentre fuera de tu residencia, puedes estar seguro de que tu data estará segura incluso si lo pierdes todo en un incendio o cualquier otra situación catastrófica. En otro artículo detallaré cómo encriptar archivos antes de subirlos a la nube.

Resumiendo, decimos entonces data > disco 1 = local; data > disco 2 = externo; data > disco 3 = nube. Cabe resaltar que en cuanto más complejo y numeroso el número de respaldos, más asegurada se encontrará la data. Aunque el esquema que presento arriba es una buena soclución para un sólo individuo, en el caso de empresas y otras entidades de mayor tamaño, se debe ajustar según la cantidad e importancia de data que se maneje. El riesgo de perder cualquier información debe mitigarse según la cantidad, uso y condición crítica que esta tenga.

Aunque perder todas las fotos familiares es, para un individuo, un evento catastrófico, sigue siendo una pérdida sentimental; por lo tanto, y hasta cierto punto, recuperable (siempre podemos crear más recuerdos). Perder toda la infraestructura de tu compañía, poniendo en riesgo a toda tu clientela es algo muchísimo más grave. Para ello un sistema de respaldo más complejo, que incorpore copias instantáneas de volumen (snapshots) cada cierto tiempo (horas, días, etc.), al igual que clonaciones mensuales o semanales de discos, sería mucho más apropiado.

### Algunos métodos de respaldo

Hay una cantidad extensa de formas para realizar copias de tus datos. También dependerán de tu sistema operativo y dispositivo. Para este artículo, me centraré en computadoras de escritorio (aunque posiblemente sirva también para laptops) con un procesador de 64 bits, y en las soluciones que son de mi agrado. Te motivo a que investigues por tu cuenta, ya que hay muchos programas que pueden lograr el mismo objetivo y que tal vez se ajusten mejor a tu caso particular.

Empezaremos con Linux, aunque luego detallaré una solución más universal. Para el pingüino, mi herramienta favorita es `rsync`. Me gusta porque es sencilla de utilizar, generalmente se encuentra preinstalada en la mayoría de las distribuciones, y si no lo está casi siempre forma parte de los repositorios oficiales de cada sabor de Linux. Te recomiendo que leas el manual. Puedes hacerlo [en línea](https://man.archlinux.org/man/rsync.1.en), o si ya instalaste el programa, desde la terminal ejecutando:

```bash
man rsync
```

Por supuesto, hay un sinnúmero de casos que se pueden aplicar con rsync, pero por ahora nos enfocaremos únicamente en un respaldo completo de tu sistema. Podemos ejecutar el siguiente comando, [según explica la wiki de Arch Linux](https://wiki.archlinux.org/title/Rsync#Full_system_backup):

```bash
rsync -aAXHv --exclude={"/dev/*","/proc/*","/sys/*","/tmp/*","/run/*","/mnt/*","/media/*","/lost+found"} / /lugar/del/respaldo
```

Esto creará un snapshot que podremos restaurar a cualquier disco (incluso uno donde nuestro sistema ya esté instalado), siempre y cuando ejecutemos el comando anterior con la fuente del respaldo y el destino en reversa. Ejemplo, para restaurar desde un sistema ya instalado:

```bash
rsync -aAXHv --exclude={"/dev/*","/proc/*","/sys/*","/tmp/*","/run/*","/mnt/*","/media/*","/lost+found"} /lugar/del/respaldo /
```

O para elegir algún lugar en específico a donde restaurar los archivos:

```bash
rsync -aAXHv --exclude={"/dev/*","/proc/*","/sys/*","/tmp/*","/run/*","/mnt/*","/media/*","/lost+found"} /lugar/del/respaldo /lugar/particular/a/restaurar
````

Otro beneficio de `rsync`, es que nos permite subir a un servidor remoto cualquier archivo, así que podríamos utilizarlo para enviar nuestro respaldo hacia él. Hay varias formas de hacerlo, así que a continuación muestro sólo un ejemplo. Asegúrate de leer el manual y ver qué parametros se ajustan a tu caso:

```bash
rsync -Pa /lugar/del/respaldo usuario@servidor:/lugar/para/almacenar
```

En este caso, especificamos `-Pa`, para modificar el comando de la siguiente manera:

* `-P` es equivalente a correr el comando con los parámetros `--partial` y `--progress`. El primero garantiza que cualquier archivo que no pueda ser transferido en su totalidad, sea eliminado para evitar problemas de corrupción. En el caso de `--progress`, nos muestra el progreso de la transferencia de archivos.
* `-a` es equivalente a `-rlptgoD`, y nos sirve para copiar de manera recursiva los archivos y mantener esencialmente todas sus propiedades intactas como permisos y demás. Para mayor información [referirse al manual](https://man.archlinux.org/man/rsync.1.en).

### Clonezilla un método (algo) más universal

Por mi parte, mi método principal de respaldo es realizar una clonación total de mi disco en una imagen restaurable utilizando el programa `clonezilla`. Este software desarrollado por [NCHC Free Software Labs](https://clonezilla.org) es bastante sencillo y poderoso. Luego de que hayas creado una imagen de tu disco, puedes restaurarla desde un disco nuevo, o reemplazar tu disco actual con el respaldo que tomaste en caso de que desees regresar a un punto anterior en tu sistema. Resulta muy útil cuando cometes algún error y deseas regresar a un momento antes de haber metido la pata.

Sólo existen dos percances con esta solución: lo primero es que no es compatible con APFS, el sistema de archivos de código cerrado que implementa Apple. ~~Otro problema es el hecho de que pagas el triple por el logo de una manzanita mordisqueada~~. El segundo asunto es que para hacer una clonación del disco que deseas copiar, no puede estar en uso. Por lo tanto, no podemos ejecutar clonezilla desde nuestro sistema operativo en vivo si deseamos respaldarlo.

Lo bueno de este último punto es que es bastante fácil de solucionar: para ello, debemos crear un medio de instalación como el que utilizamos para instalar cualquier sistema operativo, y utilizarlo para ejecutar clonezilla y asi poder respaldar los discos deseados. Como estaríamos ejecutando clonezilla desde ese medio de instalación, los discos de nuestro sistema no se encontrarían en uso.

Lo primero es procurar algún medio de instalación. Para este ejemplo, utilizaré una memoria usb. Recuerda seleccionar algo que no tenga datos importantes, pues serán eliminados. Lo segundo es [descargar clonezilla](https://clonezilla.org/downloads.php) desde su página oficial. Hay varias opciones; si no sabes cuál elegir, puedo recomendar que elijas la [versión estable](https://clonezilla.org/downloads/download.php?branch=stable) y que la descargues en formato ISO. Una vez procurado, y si estás en Linux, puedes ejecutar el siguiente comando:

```bash
dd bs=4M if=lugar/del/clonezilla.iso of=/dev/sdx conv=fsync oflag=direct status=progress
```

Recuerda reemplazar la `x` en `/dev/sdx` por la letra que pertenezca al dispositivo de instalación que vas a utilizar. Puedes utilizar `fdisk -l` o `lsblk` para averiguarla.

Si estás en Windows, la forma más sencilla de lograrlo es con la aplicación Rufus. Es la misma que usamos para crear medios de instalación para Linux desde Windows, y que ya detallaba en un artículo anterior. Parafraseando lo que dije en este:

> *Cuando hayas instalado el programa, sólo debes hacer click en donde dice «SELECT», y seleccionar el archivo ISO de Clonezilla que descargaste, y luego presionar en «START» para formatear la memoria y crear la instalación*.

Cuando tengas la memoria lista con el ISO, es sólo cuestión de insertarlo en tu PC, reiniciar y presionar la tecla antes del inicio que te permita accesar al menú de arranque de discos. Esta tecla varía dependiendo de la tarjeta madre que tengas. En mi caso es F11, pero para ti podría ser otra tecla. Algunas opciones comunes son F2 y del. Selecciona la opción que tenga el nombre de la memoria USB que utilizaste, y con ello podrás iniciar Clonezilla.

Un pequeño dato que podría ser útil es que la imagen de instalación de [Arch Linux](https://archlinux.org) ya viene con clonezilla como uno de los programas que puedes ejecutar. Sólo debes iniciar el medio de instalación como si fueras a instalar el sistema operativo y ejecutar el comando `clonezilla` para dar inicio al menú de clonación.

Esta vez no detallaré cómo utilizar clonezilla, pues eso amerita su propio artículo. Por ahora sólo referiré a la documentación que explica [cómo crear una imagen de tu disco](https://clonezilla.org/fine-print-live-doc.php?path=./clonezilla-live/doc/01_Save_disk_image/01-clonezilla-boot-menu.doc#01-clonezilla-boot-menu.doc) paso por paso y con imágenes.

### Conclusión

No hay nada más incómodo que perder data. Especialmente si esta es de importancia para nuestro diario vivir. A pesar de ello, pocas personas se preocupan por respaldar su sistema o aquellos archivos importantes que poseen. Es fácil olvidar que los discos no son interminables y que si no tomamos las precauciones necesarias, nos aguarda una catástrofe. Debemos ajustar nuestros hábitos e incorporar los respaldos dentro de ellos, ya que son una tarea importante para reducir la pérdida de información valiosa. Quizás este pensamiento sirva de algo: 

> «*Respalda múltiples veces lo que temas perder, copia aunque sea una vez lo que te de pereza recuperar, y elimina lo que tengas que no utilizas*».
